# -*- coding: utf-8 -*-

"""
a couple of variable to use throughout the app
"""

default_app_config: str = "sovtimer.apps.AaSovtimerConfig"

__version__ = "0.5.1"
__title__ = "Sovereignty Timers"
